@@ -484,28 +484,18 @@ def verifyDataIntegrity(initialFile, finalFile):
 		del inp
 		del out
 		gc.collect()
-		#copy the waveform data over
-		#figure out the type of header we have
-		headerType = None
+		#now read in the waveform data and verify the checksums all match what they should
 		for key in testIn['waveforms']:
-			tempType = getHeaderType(testIn['waveforms/'+str(key)])
-			if tempType is not None:
-				headerType = tempType
-				break
-		if headerType is not None:
-			for key in testIn['waveforms']:
-				temp = convertWaveformType(testIn['waveforms/'+str(key)])
-				if temp is not None:
-					out = testOut['waveforms/'+str(key)+'/header'][()]
-					if not np.array_equal(temp['header'], out):
-						return -7
-					del out
-					gc.collect()
-					out = testOut['waveforms/'+str(key)+'/waveform'][()]
-					if not np.array_equal(temp['waveform'], out):
-						return -8
-					del out
-					gc.collect()
+			headers = testIn['waveforms/'+str(key)+'/headers'][()]
+			waveforms = testIn['waveforms/'+str(key)+'/waveforms'][()]
+			#check if these datasets are empty or not
+			if headers.shape is not None:
+				#if they have stuff, calculate the checksums and verify it all matches
+				checksumsInit = headers['checksum']
+				calculated = np.apply_along_axis(bf.Fletcher32, 1, waveforms.view(np.uint16))
+				equal = np.array_equal(calculated, checksumsInit)
+				if not equal:
+					return -7
 		testIn.close()
 		testOut.close()
 		del testIn
